#!/usr/bin/python3

"""
Модуль, реализующий переключение сетевых интерфейсов на контроллере

"""

import sys
import os
import traceback


class Config:
    def __init__(self, logging_dir, working_dir):
        self.logging_dir = logging_dir
        self.working_dir = working_dir


def get_iq_config(project_path):
    try:
        config_m = import_module(project_path, CONFIG_FILE_NAME)
    except:
        print(traceback.format_exc())
        config_m = None

    logging_dir = os.path.join(project_path, 'log') if (config_m is None) or (not hasattr(config_m, 'LOG_DIR_PATH')) \
        else config_m.LOG_DIR_PATH
    working_dir = os.path.join(project_path, 'tmp') if (config_m is None) or (not hasattr(config_m, 'WORK_DIR_PATH')) \
        else config_m.WORK_DIR_PATH

    for dir_path in [logging_dir, working_dir]:
        if not os.path.isdir(dir_path):
            os.makedirs(dir_path)
    return Config(logging_dir, working_dir)


if __name__ == "__main__":
    project_path, module_filename = os.path.split(os.path.realpath(__file__))
    module_name = os.path.splitext(module_filename)[0]
    # print("module filename: \"{0}\"".format(module_filename))
    print("module path: \"{0}\"".format(project_path))
    print("module name: \"{0}\"".format(module_name))
    if not module_name.startswith('iq_'):
        module_name = 'iq_' + module_name
    print("final module name: \"{0}\"".format(module_name))

    if project_path not in sys.path:
        sys.path.insert(0, project_path)

    from lib.iq_network_manager import IQNetworkManager as Service
    from lib.sys_utils import import_module  # parse_file_path
    from lib.settings import CONFIG_FILE_NAME

    config = get_iq_config(project_path)

    nm = Service(module_name, config)
    nm.start()
